@@ -111,6 +111,7 @@ void CourseDialog::createLayout(QWidget *parent)
 
 void CourseDialog::createButton(QWidget *parent)
 {
+  Q_UNUSED(parent);
   pushButtonUp = new QPushButton(tr("+"));
   connect(pushButtonUp, SIGNAL(clicked()), this, SLOT(up()));
 
@@ -134,7 +135,7 @@ void CourseDialog::createTable(QWidget *parent)
   table->horizontalHeader()->hide();
   table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
   table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
-  table->setStyleSheet(ScoreColor::styleSheet());
+  //table->setStyleSheet(ScoreColor::styleSheet());
 }
 
 void CourseDialog::init(Course *course)
