@@ -219,8 +219,10 @@ Course::Course(const QXmlAttributes &attrs) {
   name = attrs.value("name");
 }
 
-Course::Course(const QDomElement node) {
-  name = node.attribute("name", "");
+Course::Course(const QDomElement node, Club * parent)
+    : club(parent)
+{
+    name = node.attribute("name", "");
 }
 
 Course::Course(QString &name, 
@@ -235,6 +237,16 @@ Course::Course(QString &name,
   }
 }
 
+Club * Course::parent()
+{
+    return club;
+}
+
+void Course::setParent(Club *parent)
+{
+    club = parent;
+}
+
 QDomElement Course::toElement(QDomDocument doc)
 {
   QDomElement node = doc.createElement("course");
@@ -252,6 +264,7 @@ int Course::update(QVector<QString> &par,
 		   QVector<QString> &hcp,
 		   QVector<QString> &len)
 {
+  Q_UNUSED(len);
   for (int i = 0; i < par.size(); i++) {
     Hole *hole = holeList.at(i);
     if (hole->getPar() != par[i])
@@ -329,6 +342,22 @@ Club::Club(QString &name)
 
 void Club::addCourse(Course *iCourse) {
   courseList << iCourse;
+  iCourse->setParent(this);
+}
+
+void Club::delCourse(Course * course) {
+    int index = courseList.indexOf(course);
+
+    if (index != -1)
+        courseList.removeAt(index);
+}
+
+bool Club::isEmpty()
+{
+    bool rc = false;
+    if (courseList.count() == 0)
+        rc = true;
+    return rc;
 }
 
 QDomElement Club::toElement(QDomDocument doc)
