@@ -50,6 +50,11 @@ class Score {
     return date < val.getDate();
   }
 
+  bool operator> (const Score& val) const 
+  { 
+    return date > val.getDate();
+  }
+
   QDomElement toElement(QDomDocument doc);
   int update(QVector<QString> &scores);
   void addHole(Hole *iHole);
@@ -65,10 +70,12 @@ class Score {
   QString club, course, date;
 };
 
+class Club;
+
 class Course {
  public:
   Course(const QXmlAttributes &attrs);
-  Course(const QDomElement node);
+  Course(const QDomElement node, Club * parent = 0);
   Course(QString &name, QVector<QString> &, QVector<QString> &);
   QDomElement toElement(QDomDocument doc);
   int update(QVector<QString> &, QVector<QString> &, QVector<QString> &);
@@ -78,10 +85,13 @@ class Course {
   QString& getName();
   QString getTotal(int what);
   void dump();
+  Club * parent();
+  void setParent(Club *parent);
 
  private:
   QList <Hole *> holeList;
   QString name;
+  Club *club;
 };
 
 class Club {
@@ -93,10 +103,12 @@ class Club {
 
   QDomElement toElement(QDomDocument doc);
   void addCourse(Course *iCourse);
+  void delCourse(Course *iCourse);
   void dump();
   QString& getName();
   Course *getCourse(int pos);
   Course *getCourse(const QString &courseName);
+  bool isEmpty();
 
   QList <Course *> getCourseList() { return courseList; } // HACK: fixme
 
