@@ -8,17 +8,19 @@
 
 #include <QMainWindow>
 #include <QTableView>
+#include <QListView>
 #include <QPushButton>
-#include <QToolBar>
 #include <QTextEdit>
 #include <QVBoxLayout>
 #include <QItemSelectionModel>
 #include <QList>
 #include <QLabel>
+#include <QActionGroup>
 #include <QXmlDefaultHandler>
 
 #include "data.h"
 #include "table-model.h"
+#include "list-model.h"
 
 class MainWindow : public QMainWindow
 {
@@ -26,9 +28,10 @@ class MainWindow : public QMainWindow
 
 public:
   MainWindow(QMainWindow *parent = 0);
-  void createLayout(QWidget *parent = 0);
-  void createTableView(QList<Score *> &, QList <Club *> &);
-  void updateTitleBar();
+  void createLayoutTable(QWidget *parent = 0);
+  void createLayoutList(QWidget *parent = 0);
+  void createListView(QList<Score *> &, QList <Club *> &);
+  void updateTitleBar(QString & msg);
   void loadScoreFile(QString &fileName, QList<Score *> &scoreList);
   void loadClubFile(QString &fileName, QList<Club *> &clubList);
   void saveScoreFile(QString &fileName, QList<Score *> &scoreList);
@@ -38,66 +41,64 @@ signals:
   void dataChanged();
 
 private slots:
-  void firstButtonClicked();
-  void lastButtonClicked();
-  void nextButtonClicked();
-  void prevButtonClicked();
+  void clickedList(const QModelIndex &index);
 
   void newScore();
+  void deleteScore();
   void editScore();
   void newCourse();
+  void deleteCourse();
   void editCourse();
   void viewStatistics();
+  void listScores();
+  void listCourses();
 
 private:
 
   void loadSettings(void);
-  Club *findClub(QString &name);
+  Club * findClub(QString &name);
+  Course * findCourse(const QString &clubName, const QString &courseName);
+  Course * findCourse();
+  Score * findScore(QString & clubName, QString & courseName);
+                               
+  void showNote(QString msg);
   void getStat(QTextEdit *);
 
+  void viewScore(Score * score, Course * course);
+  void viewCourse(Course * course);
+
   QList<Score *> scoreList;
   QList<Club *> clubList;
 
   ScoreTableModel *scoreTableModel;
+  ScoreListModel *scoreListModel;
+  CourseListModel *courseListModel;
 
   QAbstractItemModel *tableModel;
   QItemSelectionModel *selectionModel;
 
   QTableView *table;
+  QListView *list;
 
   // Layouts
-  QVBoxLayout *tableLayout;
-  QVBoxLayout *buttonLayout;
   QWidget *centralWidget;
 
   // Menus
   QMenu *menu;
 
-  // Buttons
-  QPushButton *nextButton;
-  QPushButton *prevButton;
-  QPushButton *firstButton;
-  QPushButton *lastButton;
-
-  // Toolbar
-  QToolBar *toolbar;
-
   // Actions
-  QAction *newScoreAct;
-  QAction *editScoreAct;
-  QAction *newCourseAct;
-  QAction *editCourseAct;
-  QAction *statAct;
-  QAction *firstAct;
-  QAction *lastAct;
-  QAction *nextAct;
-  QAction *prevAct;
+  QAction *newScoreAction;
+  QAction *newCourseAction;
+  QAction *statAction;
 
-  QAction *viewScoreAct;
-  QAction *viewCourseAct;
+  QActionGroup *filterGroup;
+  QAction *listScoreAction;
+  QAction *listCourseAction;
 
   void createMenus();
   void createActions();
 
-
+  // Windows
+  QMainWindow *scoreWin;
+  QMainWindow *courseWin;
 };
