@@ -17,6 +17,10 @@
 #include <QPushButton>
 #include <QDateEdit>
 #include <QLayout>
+#ifdef Q_WS_MAEMO_5
+#include <QtMaemo5/QMaemo5ValueButton>
+#include <QtMaemo5/QMaemo5DatePickSelector>
+#endif
 
 #include "data.h"
 
@@ -43,8 +47,12 @@ private slots:
 
   // Widgets
   QListWidget  *listClub;
+#ifdef Q_WS_MAEMO_5
+  QMaemo5ValueButton *dateButton;
+#else
   QLineEdit    *lineEditDate;
   QDateEdit    *date;
+#endif
   QLabel       *labelClub;
   QLabel       *labelCourse;
   QPushButton  *pushButtonNext;
