@@ -107,17 +107,17 @@ int ClubXmlHandler::parse(QString &fileName)
     QDomElement courseElement = clubElement.firstChildElement("course");
     while (!courseElement.isNull()) {
 
-      Course *course = new Course(courseElement);
-      club->addCourse(course);
+        Course *course = new Course(courseElement, club);
+        club->addCourse(course);
 
-      QDomElement holeElement = courseElement.firstChildElement("hole");
-      while (!holeElement.isNull()) {
-	Hole *hole = new Hole(holeElement);
-	course->addHole(hole);
+        QDomElement holeElement = courseElement.firstChildElement("hole");
+        while (!holeElement.isNull()) {
+            Hole *hole = new Hole(holeElement);
+            course->addHole(hole);
 
-	holeElement = holeElement.nextSiblingElement("hole");
-      }
-      courseElement = courseElement.nextSiblingElement("course");
+            holeElement = holeElement.nextSiblingElement("hole");
+        }
+        courseElement = courseElement.nextSiblingElement("course");
     }
     list << club;
     clubElement = clubElement.nextSiblingElement("club");
